import { defineEventHandler } from 'h3';
import { mount } from '@vue/test-utils';
import { h as h$1, Suspense, nextTick } from 'vue';
import { defineComponent, useRouter } from '#imports';
import NuxtRoot from '#build/root-component.mjs';

function registerEndpoint(url, handler) {
  if (!window.__app)
    return;
  window.__app.use("/_" + url, defineEventHandler(handler));
  window.__registry.add(url);
}
function mockNuxtImport(name, factory) {
  throw new Error("mockNuxtImport() is a macro and it did not get transpiled");
}

const RouterLink = defineComponent({
  functional: true,
  props: {
    to: String,
    custom: Boolean,
    replace: Boolean,
    // Not implemented
    activeClass: String,
    exactActiveClass: String,
    ariaCurrentValue: String
  },
  setup: (props, { slots }) => {
    const navigate = () => {
    };
    return () => {
      const route = props.to ? useRouter().resolve(props.to) : {};
      return props.custom ? slots.default?.({ href: props.to, navigate, route }) : h(
        "a",
        {
          href: props.to,
          onClick: (e) => {
            e.preventDefault();
            return navigate();
          }
        },
        slots
      );
    };
  }
});

async function mountSuspended(component) {
  return new Promise((resolve) => {
    const vm = mount(
      {
        setup: NuxtRoot.setup,
        render: () => h$1(
          Suspense,
          { onResolve: () => nextTick().then(() => resolve(vm)) },
          { default: () => h$1(component) }
        )
      },
      {
        global: {
          components: {
            RouterLink
          }
        }
      }
    );
  });
}

export { mockNuxtImport, mountSuspended, registerEndpoint };
